@@ -60,7 +60,7 @@ do
   TARBALL_PATH="../${PACKAGE}_${PACKAGE_VERSION}.orig.tar.${ext}"
   if [ -f "$TARBALL_PATH" ]
   then
-    cp --verbose --no-clobber "$TARBALL_PATH" "$RELEASE_DIR/"
+    cp --verbose --update=none "$TARBALL_PATH" "$RELEASE_DIR/"
     # Exit loop after finding and copying the first tarball
     break
   fi
@@ -134,12 +134,12 @@ fi
 # If the container returned an error code, stop here after cleanup completed
 if [ -n "$FAILURE" ]
 then
-  log_error "Source build failed - see logs in file://$RELEASE_DIR for details"
+  log_error "Source build failed - see logs in $(clickable_link "$RELEASE_DIR") for details"
   exit 1
 fi
 
 echo
-log_info "Artifacts at file://$RELEASE_DIR"
+log_info "Artifacts at $(clickable_link "$RELEASE_DIR")"
 
 if [ -n "${PREVIOUS_SUCCESSFUL_RELEASE_DIRS[0]}" ]
 then
@@ -148,7 +148,7 @@ then
   log_info "  meld ${PREVIOUS_SUCCESSFUL_RELEASE_DIRS[0]} $RELEASE_DIR &"
   if [ -f "$RELEASE_DIR/diffoscope.html" ]
   then
-    log_info "  browse file://$RELEASE_DIR/diffoscope.html"
+    log_info "  browse $(clickable_link "$RELEASE_DIR/diffoscope.html")"
   fi
 fi
 
@@ -159,6 +159,6 @@ then
   log_info "  meld ${LAST_TAGGED_SUCCESSFUL_RELEASE_DIRS[0]} $RELEASE_DIR &"
   if [ -f "$RELEASE_DIR/diffoscope.html" ]
   then
-    log_info "  browse file://$RELEASE_DIR/diffoscope.last-tagged.html"
+    log_info "  browse $(clickable_link "$RELEASE_DIR/diffoscope.last-tagged.html")"
   fi
 fi
